How to cite **naturf**
======================

Sweet-Breu, L. T., Rexer, E., Vernon, C. R., & Allen-Dumas, M. R. naturf: a package for generating urban parameters for numerical weather modeling [Computer software]. https://doi.org/10.5281/zenodo.7036191
